@@ -45,7 +45,9 @@ def health_check():
                 and decoded_stdout.startswith("pandoc")
             )
         except subprocess.CalledProcessError as e:
-            errors.append(f"pandoc --version failed: {type(e)} {e}, stdout: {decoded_stdout}")
+            errors.append(f"pandoc --version failed: {type(e)} {e}")
+        if not decoded_stdout.startswith("pandoc"):
+            errors.append(f"bad stdout from pandoc: {decoded_stdout}")
     else:
         errors.append(f"pandoc not found at {pandoc_path}")
 
